summaryrefslogtreecommitdiffstats
path: root/kexi/widget
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:38:41 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:38:41 -0600
commitf0de9e167e289ab7dc33e57f077c1f04ec7c68c8 (patch)
tree1fc538e179833e62caec21956bfe47a252be5a72 /kexi/widget
parent11191ef0b9908604d1d7aaca382b011ef22c454c (diff)
downloadkoffice-f0de9e167e289ab7dc33e57f077c1f04ec7c68c8.tar.gz
koffice-f0de9e167e289ab7dc33e57f077c1f04ec7c68c8.zip
Remove additional unneeded tq method conversions
Diffstat (limited to 'kexi/widget')
-rw-r--r--kexi/widget/kexibrowser.cpp8
-rw-r--r--kexi/widget/kexicharencodingcombobox.cpp2
-rw-r--r--kexi/widget/kexicustompropertyfactory_p.cpp2
-rw-r--r--kexi/widget/kexidataawareview.cpp2
-rw-r--r--kexi/widget/kexidatatable.cpp4
-rw-r--r--kexi/widget/kexidbconnectionwidgetbase.ui2
-rw-r--r--kexi/widget/kexifieldcombobox.cpp2
-rw-r--r--kexi/widget/kexiprjtypeselectorbase.ui4
-rw-r--r--kexi/widget/kexipropertyeditorview.cpp2
-rw-r--r--kexi/widget/kexiscrollview.cpp10
-rw-r--r--kexi/widget/pixmapcollection.cpp6
-rw-r--r--kexi/widget/relations/kexirelationview.h2
-rw-r--r--kexi/widget/relations/kexirelationviewtable.cpp4
-rw-r--r--kexi/widget/relations/kexirelationwidget.h2
-rw-r--r--kexi/widget/tableview/kexicomboboxtableedit.cpp4
-rw-r--r--kexi/widget/tableview/kexidataawareobjectiface.cpp60
-rw-r--r--kexi/widget/tableview/kexidataawareobjectiface.h22
-rw-r--r--kexi/widget/tableview/kexidataawarepropertyset.cpp2
-rw-r--r--kexi/widget/tableview/kexidataawarepropertyset.h2
-rw-r--r--kexi/widget/tableview/kexidatetableedit.cpp2
-rw-r--r--kexi/widget/tableview/kexitableitem.cpp2
-rw-r--r--kexi/widget/tableview/kexitableview.cpp34
-rw-r--r--kexi/widget/tableview/kexitableview.h24
-rw-r--r--kexi/widget/tableview/kexitableviewdata.cpp36
-rw-r--r--kexi/widget/tableview/kexitableviewdata.h26
-rw-r--r--kexi/widget/utils/kexicontextmenuutils.cpp6
-rw-r--r--kexi/widget/utils/kexidatetimeformatter.cpp8
-rw-r--r--kexi/widget/utils/kexiflowlayout.cpp10
-rw-r--r--kexi/widget/utils/kexiflowlayout.h2
-rw-r--r--kexi/widget/utils/kexigradientwidget.cpp8
-rw-r--r--kexi/widget/utils/kexigradientwidget.h4
-rw-r--r--kexi/widget/utils/kexirecordnavigator.h2
32 files changed, 153 insertions, 153 deletions
diff --git a/kexi/widget/kexibrowser.cpp b/kexi/widget/kexibrowser.cpp
index 4c279382..af893ddf 100644
--- a/kexi/widget/kexibrowser.cpp
+++ b/kexi/widget/kexibrowser.cpp
@@ -435,7 +435,7 @@ KexiBrowser::slotContextMenu(KListView* /*list*/, TQListViewItem *item, const TQ
pm->changeTitle(m_partPopupTitle_id, *bit->pixmap(0), title_text);
/* KexiPart::Part* part = Kexi::partManager().part(bit->info());
if (part)
- m_newObjectAction->setText(i18n("&Create Object: %1...").tqarg( part->instanceName() ));
+ m_newObjectAction->setText(i18n("&Create Object: %1...").arg( part->instanceName() ));
else
m_newObjectAction->setText(i18n("&Create Object..."));
m_newObjectAction->setIconSet( SmallIconSet(bit->info()->itemIcon()) );*/
@@ -523,14 +523,14 @@ KexiBrowser::slotSelectionChanged(TQListViewItem* i)
m_prevSelectedPart = part;
if (part) {
if (m_newObjectAction) {
- m_newObjectAction->setText(i18n("&Create Object: %1...").tqarg( part->instanceCaption() ));
+ m_newObjectAction->setText(i18n("&Create Object: %1...").arg( part->instanceCaption() ));
m_newObjectAction->setIcon( part->info()->createItemIcon() );
if (m_features & Toolbar) {
m_newObjectToolButton->setIconSet( part->info()->createItemIcon() );
TQToolTip::add(m_newObjectToolButton,
- i18n("Create object: %1").tqarg( part->instanceCaption().lower() ));
+ i18n("Create object: %1").arg( part->instanceCaption().lower() ));
TQWhatsThis::add(m_newObjectToolButton,
- i18n("Creates a new object: %1").tqarg( part->instanceCaption().lower() ));
+ i18n("Creates a new object: %1").arg( part->instanceCaption().lower() ));
}
}
} else {
diff --git a/kexi/widget/kexicharencodingcombobox.cpp b/kexi/widget/kexicharencodingcombobox.cpp
index de6254b7..84038dcd 100644
--- a/kexi/widget/kexicharencodingcombobox.cpp
+++ b/kexi/widget/kexicharencodingcombobox.cpp
@@ -66,7 +66,7 @@ KexiCharacterEncodingComboBox::KexiCharacterEncodingComboBox(
if (!defaultEncodingDescriptiveName.isEmpty()) {
m_defaultEncodingAdded = true;
TQString desc = i18n("Text encoding: Default", "Default: %1")
- .tqarg(defaultEncodingDescriptiveName);
+ .arg(defaultEncodingDescriptiveName);
insertItem( desc, 0 );
if (_selectedEncoding==defaultEncoding) {
setCurrentItem(0);
diff --git a/kexi/widget/kexicustompropertyfactory_p.cpp b/kexi/widget/kexicustompropertyfactory_p.cpp
index e06b084b..2cdd0bfc 100644
--- a/kexi/widget/kexicustompropertyfactory_p.cpp
+++ b/kexi/widget/kexicustompropertyfactory_p.cpp
@@ -101,7 +101,7 @@ void KexiIdentifierPropertyEdit::setValue(const TQVariant &value, bool emitChang
TQString identifier( KexiUtils::string2Identifier(string) );
if (identifier!=string)
kdDebug() << TQString("KexiIdentifierPropertyEdit::setValue(): "
- "String \"%1\" converted to identifier \"%2\".").tqarg(string).tqarg(identifier) << endl;
+ "String \"%1\" converted to identifier \"%2\".").arg(string).arg(identifier) << endl;
StringEdit::setValue( identifier, emitChange );
}
diff --git a/kexi/widget/kexidataawareview.cpp b/kexi/widget/kexidataawareview.cpp
index c6eb39d3..29bd06d0 100644
--- a/kexi/widget/kexidataawareview.cpp
+++ b/kexi/widget/kexidataawareview.cpp
@@ -241,7 +241,7 @@ void KexiDataAwareView::slotCellSelected(int /*col*/, int row)
void KexiDataAwareView::deleteAllRows()
{
- m_dataAwareObject->deleteAllRows(true/*ask*/, true/*tqrepaint*/);
+ m_dataAwareObject->deleteAllRows(true/*ask*/, true/*repaint*/);
}
void KexiDataAwareView::deleteCurrentRow()
diff --git a/kexi/widget/kexidatatable.cpp b/kexi/widget/kexidatatable.cpp
index 09680b14..0be99a4a 100644
--- a/kexi/widget/kexidatatable.cpp
+++ b/kexi/widget/kexidatatable.cpp
@@ -42,10 +42,10 @@ KexiDataTable::KexiDataTable(KexiMainWindow *mainWin, TQWidget *parent,
KexiTableView *view;
if (dbAware)
view = new KexiDataTableView(this,
- TQString("%1_datatableview").tqarg(name ? name : "KexiDataTableView").latin1());
+ TQString("%1_datatableview").arg(name ? name : "KexiDataTableView").latin1());
else
view = new KexiTableView(0, this,
- TQString("%1_tableview").tqarg(name ? name : "KexiTableView").latin1());
+ TQString("%1_tableview").arg(name ? name : "KexiTableView").latin1());
KexiDataAwareView::init( view, view, view );
}
diff --git a/kexi/widget/kexidbconnectionwidgetbase.ui b/kexi/widget/kexidbconnectionwidgetbase.ui
index 463d8797..02fe2853 100644
--- a/kexi/widget/kexidbconnectionwidgetbase.ui
+++ b/kexi/widget/kexidbconnectionwidgetbase.ui
@@ -337,7 +337,7 @@
<property name="text">
<string>&amp;Title (optional):</string>
</property>
- <property name="tqalignment">
+ <property name="alignment">
<set>AlignTop</set>
</property>
<property name="buddy" stdset="0">
diff --git a/kexi/widget/kexifieldcombobox.cpp b/kexi/widget/kexifieldcombobox.cpp
index b9c64635..d41d93a2 100644
--- a/kexi/widget/kexifieldcombobox.cpp
+++ b/kexi/widget/kexifieldcombobox.cpp
@@ -182,7 +182,7 @@ void KexiFieldComboBox::setFieldOrExpression(int index)
index++; //skip 1st empty item
if (index>=count()) {
kexiwarn << TQString("KexiFieldComboBox::setFieldOrExpression(int index): index %1 "
- "out of range (0..%2)").tqarg(index).tqarg(count()-1) << endl;
+ "out of range (0..%2)").arg(index).arg(count()-1) << endl;
index = -1;
}
if (index<=0) {
diff --git a/kexi/widget/kexiprjtypeselectorbase.ui b/kexi/widget/kexiprjtypeselectorbase.ui
index 059bf080..c6ff117a 100644
--- a/kexi/widget/kexiprjtypeselectorbase.ui
+++ b/kexi/widget/kexiprjtypeselectorbase.ui
@@ -88,7 +88,7 @@
<property name="scaledContents">
<bool>true</bool>
</property>
- <property name="tqalignment">
+ <property name="alignment">
<set>AlignVCenter|AlignLeft</set>
</property>
</widget>
@@ -110,7 +110,7 @@
<property name="scaledContents">
<bool>true</bool>
</property>
- <property name="tqalignment">
+ <property name="alignment">
<set>AlignVCenter|AlignLeft</set>
</property>
</widget>
diff --git a/kexi/widget/kexipropertyeditorview.cpp b/kexi/widget/kexipropertyeditorview.cpp
index 122d9514..e2a5ac31 100644
--- a/kexi/widget/kexipropertyeditorview.cpp
+++ b/kexi/widget/kexipropertyeditorview.cpp
@@ -76,7 +76,7 @@ void KexiObjectInfoLabel::updateName()
if (txt.isEmpty())
txt = m_objectName;
else if (!m_objectName.isEmpty())
- txt += TQString(" \"%1\"").tqarg(m_objectName);
+ txt += TQString(" \"%1\"").arg(m_objectName);
m_objectNameLabel->setText(txt);
}
diff --git a/kexi/widget/kexiscrollview.cpp b/kexi/widget/kexiscrollview.cpp
index 7bdfd12e..04beace6 100644
--- a/kexi/widget/kexiscrollview.cpp
+++ b/kexi/widget/kexiscrollview.cpp
@@ -173,11 +173,11 @@ KexiScrollView::refreshContentsSize()
change = true;
}
if (change) {
- tqrepaint();
- viewport()->tqrepaint();
+ repaint();
+ viewport()->repaint();
repaintContents();
updateContents(0, 0, 2000,2000);
- clipper()->tqrepaint();
+ clipper()->repaint();
resizeContents(w, h);
}
@@ -257,8 +257,8 @@ KexiScrollView::contentsMouseMoveEvent(TQMouseEvent *ev)
for(TQObject *o = list->first(); o; o = list->next())
{
TQWidget *w = (TQWidget*)o;
- tmpx = TQMAX(tmpx, (w->tqgeometry().right() + 10));
- tmpy = TQMAX(tmpy, (w->tqgeometry().bottom() + 10));
+ tmpx = TQMAX(tmpx, (w->geometry().right() + 10));
+ tmpy = TQMAX(tmpy, (w->geometry().bottom() + 10));
}
delete list;
diff --git a/kexi/widget/pixmapcollection.cpp b/kexi/widget/pixmapcollection.cpp
index 19875521..cee4f360 100644
--- a/kexi/widget/pixmapcollection.cpp
+++ b/kexi/widget/pixmapcollection.cpp
@@ -232,7 +232,7 @@ TQString LoadIconDialog::iconName()
/// Pixmap Collection Editor Dialog
PixmapCollectionEditor::PixmapCollectionEditor(PixmapCollection *collection, TQWidget *parent)
: KDialogBase(parent, "pixcollection_dialog", true,
- i18n("Edit Pixmap Collection: %1").tqarg(collection->collectionName()), Close, Close, false)
+ i18n("Edit Pixmap Collection: %1").arg(collection->collectionName()), Close, Close, false)
{
m_collection = collection;
TQFrame *frame = makeMainWidget();
@@ -312,7 +312,7 @@ PixmapCollectionEditor::removeItem()
int confirm = KMessageBox::questionYesNo(parentWidget(), TQString("<qt>")+
i18n("Do you want to remove item \"%1\" from collection \"%2\"?")
- .tqarg(item->text()).tqarg(m_collection->collectionName()) + "</qt>");
+ .arg(item->text()).arg(m_collection->collectionName()) + "</qt>");
if(confirm == KMessageBox::No)
return;
@@ -373,7 +373,7 @@ PixmapCollectionEditor::displayMenu(TQIconViewItem *it, const TQPoint &p)
//// A Dialog to choose a pixmap from the PixmapCollection
PixmapCollectionChooser::PixmapCollectionChooser(PixmapCollection *collection, const TQString &selectedItem, TQWidget *parent)
-: KDialogBase(parent, "pixchoose_dialog", true, i18n("Select Pixmap From %1").tqarg(collection->collectionName()),
+: KDialogBase(parent, "pixchoose_dialog", true, i18n("Select Pixmap From %1").arg(collection->collectionName()),
User1|Ok|Cancel, Ok, false, KGuiItem(i18n("Edit Collection...")))
{
m_collection = collection;
diff --git a/kexi/widget/relations/kexirelationview.h b/kexi/widget/relations/kexirelationview.h
index 404fbcbe..33d988b9 100644
--- a/kexi/widget/relations/kexirelationview.h
+++ b/kexi/widget/relations/kexirelationview.h
@@ -78,7 +78,7 @@ class KEXIRELATIONSVIEW_EXPORT KexiRelationView : public TQScrollView
TablesDict* tables() { return &m_tables; }
/*! Adds a table \a t to the area. This changes only visual representation.
- If \a rect is valid, table widget tqgeometry will be initialized.
+ If \a rect is valid, table widget geometry will be initialized.
\return added table container or 0 on failure.
*/
KexiRelationViewTableContainer* addTableContainer(KexiDB::TableSchema *t,
diff --git a/kexi/widget/relations/kexirelationviewtable.cpp b/kexi/widget/relations/kexirelationviewtable.cpp
index ea1682f7..b40b9761 100644
--- a/kexi/widget/relations/kexirelationviewtable.cpp
+++ b/kexi/widget/relations/kexirelationviewtable.cpp
@@ -140,7 +140,7 @@ void KexiRelationViewTableContainer::setFocus()
m_tableView->setPalette(p);*/
raise();
- tqrepaint();
+ repaint();
emit gotFocus();
}
@@ -166,7 +166,7 @@ void KexiRelationViewTableContainer::unsetFocus()
m_tableView->setPalette(p);*/
clearFocus();
- tqrepaint();
+ repaint();
}
diff --git a/kexi/widget/relations/kexirelationwidget.h b/kexi/widget/relations/kexirelationwidget.h
index 713ce8fc..6899a434 100644
--- a/kexi/widget/relations/kexirelationwidget.h
+++ b/kexi/widget/relations/kexirelationwidget.h
@@ -76,7 +76,7 @@ class KEXIRELATIONSVIEW_EXPORT KexiRelationWidget : public KexiViewBase
public slots:
/*! Adds a table \a t to the area. This changes only visual representation.
- If \a rect is valid, table widget rtqgeometry will be initialized.
+ If \a rect is valid, table widget rgeometry will be initialized.
*/
void addTable(KexiDB::TableSchema *t, const TQRect &rect = TQRect());
diff --git a/kexi/widget/tableview/kexicomboboxtableedit.cpp b/kexi/widget/tableview/kexicomboboxtableedit.cpp
index 37ababa5..f45eb0e2 100644
--- a/kexi/widget/tableview/kexicomboboxtableedit.cpp
+++ b/kexi/widget/tableview/kexicomboboxtableedit.cpp
@@ -350,8 +350,8 @@ bool KexiComboBoxTableEdit::eventFilter( TQObject *o, TQEvent *e )
if (!column()->isReadOnly() && e->type()==TQEvent::MouseButtonPress && m_scrollView) {
TQPoint gp = TQT_TQMOUSEEVENT(e)->globalPos()
+ TQPoint(m_scrollView->childX(d->button), m_scrollView->childY(d->button));
- TQRect r(d->button->mapToGlobal(d->button->tqgeometry().topLeft()),
- d->button->mapToGlobal(d->button->tqgeometry().bottomRight()));
+ TQRect r(d->button->mapToGlobal(d->button->geometry().topLeft()),
+ d->button->mapToGlobal(d->button->geometry().bottomRight()));
if (TQT_BASE_OBJECT(o)==TQT_BASE_OBJECT(popup()) && popup()->isVisible() && r.contains( gp )) {
m_mouseBtnPressedWhenPopupVisible = true;
}
diff --git a/kexi/widget/tableview/kexidataawareobjectiface.cpp b/kexi/widget/tableview/kexidataawareobjectiface.cpp
index 721cb2d8..ce0b7695 100644
--- a/kexi/widget/tableview/kexidataawareobjectiface.cpp
+++ b/kexi/widget/tableview/kexidataawareobjectiface.cpp
@@ -539,8 +539,8 @@ void KexiDataAwareObjectInterface::setCursorPosition(int row, int col/*=-1*/, bo
if ( forceSet || m_curRow != newrow || m_curCol != newcol )
{
- kexidbg << "setCursorPosition(): " <<TQString("old:%1,%2 new:%3,%4").tqarg(m_curCol)
- .tqarg(m_curRow).tqarg(newcol).tqarg(newrow) << endl;
+ kexidbg << "setCursorPosition(): " <<TQString("old:%1,%2 new:%3,%4").arg(m_curCol)
+ .arg(m_curRow).arg(newcol).arg(newrow) << endl;
// cursor moved: get rid of editor
if (m_editor) {
@@ -645,7 +645,7 @@ void KexiDataAwareObjectInterface::setCursorPosition(int row, int col/*=-1*/, bo
}
else {
kdDebug(44021) << TQString("NOW item at %1 (%2) is current")
- .tqarg(m_curRow).tqarg((ulong)itemAt(m_curRow)) << endl;
+ .arg(m_curRow).arg((ulong)itemAt(m_curRow)) << endl;
//NOT EFFECTIVE!!!!!!!!!!!
//set item iterator
if (!newRowInserted && isInsertingEnabled() && m_currentItem == m_insertItem && m_curRow == (rows()-1)) {
@@ -838,7 +838,7 @@ bool KexiDataAwareObjectInterface::cancelRowEdit()
// viewport()->width(), d->rowHeight*3 + (m_navPanel ? m_navPanel->height() : 0)*3 );
// updateContents(); //js: above did not work well so we do that dirty
updateWidgetContents();
-//TODO: still doesn't tqrepaint properly!!
+//TODO: still doesn't repaint properly!!
// TQSize s(tableSize());
// resizeContents(s.width(), s.height());
updateWidgetContentsSize();
@@ -940,7 +940,7 @@ bool KexiDataAwareObjectInterface::acceptEditor()
if (!m_errorMessagePopup) {
// m_errorMessagePopup->close();
m_errorMessagePopup = new KexiArrowTip(
- i18n("Error: %1").tqarg(m_editor->columnInfo()->field->typeName())+"?",
+ i18n("Error: %1").arg(m_editor->columnInfo()->field->typeName())+"?",
dynamic_cast<TQWidget*>(this));
m_errorMessagePopup->move(
par->mapToGlobal(edit->pos()) + TQPoint(6, edit->height() + 0) );
@@ -954,8 +954,8 @@ bool KexiDataAwareObjectInterface::acceptEditor()
if (m_editor->field()->isNotNull() && !autoIncColumnCanBeOmitted) {
kdDebug() << "KexiDataAwareObjectInterface::acceptEditor(): NULL NOT ALLOWED!" << endl;
res = Validator::Error;
-// msg = Validator::msgColumnNotEmpty().tqarg(m_editor->columnInfo()->field->captionOrName())
- msg = Validator::msgColumnNotEmpty().tqarg(m_editor->field()->captionOrName())
+// msg = Validator::msgColumnNotEmpty().arg(m_editor->columnInfo()->field->captionOrName())
+ msg = Validator::msgColumnNotEmpty().arg(m_editor->field()->captionOrName())
+ "\n\n" + Kexi::msgYouCanImproveData();
desc = i18n("The column's constraint is declared as NOT NULL.");
editCurrentCellAgain = true;
@@ -976,8 +976,8 @@ bool KexiDataAwareObjectInterface::acceptEditor()
if (m_editor->field()->isNotEmpty() && !autoIncColumnCanBeOmitted) {
kdDebug() << "KexiDataAwareObjectInterface::acceptEditor(): EMPTY NOT ALLOWED!" << endl;
res = Validator::Error;
-// msg = Validator::msgColumnNotEmpty().tqarg(m_editor->columnInfo()->field->captionOrName())
- msg = Validator::msgColumnNotEmpty().tqarg(m_editor->field()->captionOrName())
+// msg = Validator::msgColumnNotEmpty().arg(m_editor->columnInfo()->field->captionOrName())
+ msg = Validator::msgColumnNotEmpty().arg(m_editor->field()->captionOrName())
+ "\n\n" + Kexi::msgYouCanImproveData();
desc = i18n("The column's constraint is declared as NOT EMPTY.");
editCurrentCellAgain = true;
@@ -994,8 +994,8 @@ bool KexiDataAwareObjectInterface::acceptEditor()
if (m_editor->field()->isNotNull() && !autoIncColumnCanBeOmitted) {
kdDebug() << "KexiDataAwareObjectInterface::acceptEditor(): NEITHER NULL NOR EMPTY VALUE CAN BE SET!" << endl;
res = Validator::Error;
-// msg = Validator::msgColumnNotEmpty().tqarg(m_editor->columnInfo()->field->captionOrName())
- msg = Validator::msgColumnNotEmpty().tqarg(m_editor->field()->captionOrName())
+// msg = Validator::msgColumnNotEmpty().arg(m_editor->columnInfo()->field->captionOrName())
+ msg = Validator::msgColumnNotEmpty().arg(m_editor->field()->captionOrName())
+ "\n\n" + Kexi::msgYouCanImproveData();
desc = i18n("The column's constraint is declared as NOT EMPTY and NOT NULL.");
editCurrentCellAgain = true;
@@ -1251,7 +1251,7 @@ void KexiDataAwareObjectInterface::insertItem(KexiTableItem *newItem, int row)
m_curRow++;
}
- m_data->insertRow(*newItem, row, true /*tqrepaint*/);
+ m_data->insertRow(*newItem, row, true /*repaint*/);
if (changeCurrentRow) {
//update iter...
@@ -1281,15 +1281,15 @@ void KexiDataAwareObjectInterface::insertItem(KexiTableItem *newItem, int row)
*/
}
-void KexiDataAwareObjectInterface::slotRowInserted(KexiTableItem *item, bool tqrepaint)
+void KexiDataAwareObjectInterface::slotRowInserted(KexiTableItem *item, bool repaint)
{
int row = m_data->findRef(item);
- slotRowInserted( item, row, tqrepaint );
+ slotRowInserted( item, row, repaint );
}
-void KexiDataAwareObjectInterface::slotRowInserted(KexiTableItem * /*item*/, uint row, bool tqrepaint)
+void KexiDataAwareObjectInterface::slotRowInserted(KexiTableItem * /*item*/, uint row, bool repaint)
{
- if (tqrepaint && (int)row<rows()) {
+ if (repaint && (int)row<rows()) {
updateWidgetContentsSize();
/* updateAllVisibleRowsBelow() used instead
@@ -1317,7 +1317,7 @@ void KexiDataAwareObjectInterface::slotRowInserted(KexiTableItem * /*item*/, uin
}
}
-tristate KexiDataAwareObjectInterface::deleteAllRows(bool ask, bool tqrepaint)
+tristate KexiDataAwareObjectInterface::deleteAllRows(bool ask, bool repaint)
{
if (!hasData())
return true;
@@ -1331,7 +1331,7 @@ tristate KexiDataAwareObjectInterface::deleteAllRows(bool ask, bool tqrepaint)
tableName.append("\"");
}
if (KMessageBox::Cancel == KMessageBox::warningContinueCancel(dynamic_cast<TQWidget*>(this),
- i18n("Do you want to clear the contents of table %1?").tqarg(tableName),
+ i18n("Do you want to clear the contents of table %1?").arg(tableName),
0, KGuiItem(i18n("&Clear Contents")) ))
return cancelled;
}
@@ -1339,10 +1339,10 @@ tristate KexiDataAwareObjectInterface::deleteAllRows(bool ask, bool tqrepaint)
cancelRowEdit();
// acceptRowEdit();
// m_verticalHeader->clear();
- const bool repaintLater = tqrepaint && m_spreadSheetMode;
+ const bool repaintLater = repaint && m_spreadSheetMode;
const int oldRows = rows();
- bool res = m_data->deleteAllRows(tqrepaint && !repaintLater);
+ bool res = m_data->deleteAllRows(repaint && !repaintLater);
if (res) {
if (m_spreadSheetMode) {
@@ -1359,21 +1359,21 @@ tristate KexiDataAwareObjectInterface::deleteAllRows(bool ask, bool tqrepaint)
// m_verticalHeader->setCurrentRow(-1);
// d->pUpdateTimer->start(1,true);
-// if (tqrepaint)
-// viewport()->tqrepaint();
+// if (repaint)
+// viewport()->repaint();
return res;
}
-void KexiDataAwareObjectInterface::clearColumns(bool tqrepaint)
+void KexiDataAwareObjectInterface::clearColumns(bool repaint)
{
cancelRowEdit();
m_data->clearInternal();
- clearColumnsInternal(tqrepaint);
+ clearColumnsInternal(repaint);
updateIndicesForVisibleValues();
- if (tqrepaint)
-// viewport()->tqrepaint();
+ if (repaint)
+// viewport()->repaint();
//OK?
updateWidgetContents();
@@ -1393,7 +1393,7 @@ void KexiDataAwareObjectInterface::clearColumns(bool tqrepaint)
m_verticalHeader->setCurrentRow(-1);
- viewport()->tqrepaint();
+ viewport()->repaint();
// d->pColumnTypes.resize(0);
// d->pColumnModes.resize(0);
@@ -1490,9 +1490,9 @@ void KexiDataAwareObjectInterface::setEmptyRowInsertingEnabled(bool set)
}
void KexiDataAwareObjectInterface::slotAboutToDeleteRow(KexiTableItem& item,
- KexiDB::ResultInfo* /*result*/, bool tqrepaint)
+ KexiDB::ResultInfo* /*result*/, bool repaint)
{
- if (tqrepaint) {
+ if (repaint) {
m_rowWillBeDeleted = m_data->findRef(&item);
}
}
@@ -1534,7 +1534,7 @@ bool KexiDataAwareObjectInterface::deleteItem(KexiTableItem *item)/*, bool moveC
const bool lastRowDeleted = m_spreadSheetMode && m_data->last() == item; //we need to know this so we
//can return to the last row
//after reinserting it
- if (!m_data->deleteRow(*item, true /*tqrepaint*/)) {
+ if (!m_data->deleteRow(*item, true /*repaint*/)) {
/*const int button =*/
showErrorMessageForResult( m_data->result() );
// if (KMessageBox::No == button) {
diff --git a/kexi/widget/tableview/kexidataawarepropertyset.cpp b/kexi/widget/tableview/kexidataawarepropertyset.cpp
index dde99b31..3b9fe3af 100644
--- a/kexi/widget/tableview/kexidataawarepropertyset.cpp
+++ b/kexi/widget/tableview/kexidataawarepropertyset.cpp
@@ -206,7 +206,7 @@ void KexiDataAwarePropertySet::slotRowsDeleted( const TQValueList<int> &rows )
}
//void KexiDataAwarePropertySet::slotEmptyRowInserted(KexiTableItem*, uint /*index*/)
-void KexiDataAwarePropertySet::slotRowInserted(KexiTableItem*, uint row, bool /*tqrepaint*/)
+void KexiDataAwarePropertySet::slotRowInserted(KexiTableItem*, uint row, bool /*repaint*/)
{
m_view->setDirty();
diff --git a/kexi/widget/tableview/kexidataawarepropertyset.h b/kexi/widget/tableview/kexidataawarepropertyset.h
index b2c66f96..8db82ba2 100644
--- a/kexi/widget/tableview/kexidataawarepropertyset.h
+++ b/kexi/widget/tableview/kexidataawarepropertyset.h
@@ -127,7 +127,7 @@ class KEXIDATATABLE_EXPORT KexiDataAwarePropertySet : public TQObject
void slotRowsDeleted( const TQValueList<int> &rows );
//! Called on \a row insertion in a tableview.
- void slotRowInserted(KexiTableItem* item, uint row, bool tqrepaint);
+ void slotRowInserted(KexiTableItem* item, uint row, bool repaint);
//! Called on selecting another cell in a tableview.
void slotCellSelected(int, int row);
diff --git a/kexi/widget/tableview/kexidatetableedit.cpp b/kexi/widget/tableview/kexidatetableedit.cpp
index b68b4787..49bb8a0d 100644
--- a/kexi/widget/tableview/kexidatetableedit.cpp
+++ b/kexi/widget/tableview/kexidatetableedit.cpp
@@ -163,7 +163,7 @@ void
KexiDateTableEdit::slotDateChanged(TQDate date)
{
m_edit->setDate(date);
- tqrepaint();
+ repaint();
}
void
diff --git a/kexi/widget/tableview/kexitableitem.cpp b/kexi/widget/tableview/kexitableitem.cpp
index 659e341e..d398dabb 100644
--- a/kexi/widget/tableview/kexitableitem.cpp
+++ b/kexi/widget/tableview/kexitableitem.cpp
@@ -55,7 +55,7 @@ KexiTableItem::clearValues()
void
KexiTableItem::debug() const
{
- TQString s = TQString("KexiTableItem (%1 items)").tqarg(size());
+ TQString s = TQString("KexiTableItem (%1 items)").arg(size());
for (uint i = 0; i < size(); i++)
s.append( TQString::number(i)+":"+at(i).toString()+" " );
kexidbg << s << endl;
diff --git a/kexi/widget/tableview/kexitableview.cpp b/kexi/widget/tableview/kexitableview.cpp
index 35ad2369..da1c2f20 100644
--- a/kexi/widget/tableview/kexitableview.cpp
+++ b/kexi/widget/tableview/kexitableview.cpp
@@ -366,7 +366,7 @@ void KexiTableView::updateWidgetContentsSize()
void KexiTableView::slotRowsDeleted( const TQValueList<int> &rows )
{
- viewport()->tqrepaint();
+ viewport()->repaint();
updateWidgetContentsSize();
setCursorPosition(TQMAX(0, (int)m_curRow - (int)rows.count()), -1, true);
}
@@ -384,7 +384,7 @@ void KexiTableView::setFont( const TQFont &font )
updateFonts(true);
}
-void KexiTableView::updateFonts(bool tqrepaint)
+void KexiTableView::updateFonts(bool repaint)
{
#ifdef TQ_WS_WIN
d->rowHeight = fontMetrics().lineSpacing() + 4;
@@ -407,7 +407,7 @@ void KexiTableView::updateFonts(bool tqrepaint)
KexiDisplayUtils::initDisplayForAutonumberSign(d->autonumberSignDisplayParameters, this);
KexiDisplayUtils::initDisplayForDefaultValue(d->defaultValueDisplayParameters, this);
- if (tqrepaint)
+ if (repaint)
updateContents();
}
@@ -425,7 +425,7 @@ void KexiTableView::updateAllVisibleRowsBelow(int row)
clipper()->width(), clipper()->height() - (rowPos(row) - contentsY()) );
}
-void KexiTableView::clearColumnsInternal(bool /*tqrepaint*/)
+void KexiTableView::clearColumnsInternal(bool /*repaint*/)
{
while(m_horizontalHeader->count()>0)
m_horizontalHeader->removeLabel(0);
@@ -614,7 +614,7 @@ void KexiTableView::drawContents( TQPainter *p, int cx, int cy, int cw, int ch)
bool paintOnlyInsertRow = false;
/* kdDebug(44021) << TQString(" KexiTableView::drawContents(cx:%1 cy:%2 cw:%3 ch:%4)")
- .tqarg(cx).tqarg(cy).tqarg(cw).tqarg(ch) << endl;*/
+ .arg(cx).arg(cy).arg(cw).arg(ch) << endl;*/
if (rowlast == -1) {
rowlast = rows() - 1;
@@ -931,9 +931,9 @@ void KexiTableView::paintEmptyArea( TQPainter *p, int cx, int cy, int cw, int ch
// ts.setWidth( TQMIN( ts.width(), visibleWidth() ) );
// ts.setHeight( TQMIN( ts.height() - (m_navPanel ? m_navPanel->height() : 0), visibleHeight()) );
/* kdDebug(44021) << TQString(" (cx:%1 cy:%2 cw:%3 ch:%4)")
- .tqarg(cx).tqarg(cy).tqarg(cw).tqarg(ch) << endl;
+ .arg(cx).arg(cy).arg(cw).arg(ch) << endl;
kdDebug(44021) << TQString(" (w:%3 h:%4)")
- .tqarg(ts.width()).tqarg(ts.height()) << endl;*/
+ .arg(ts.width()).arg(ts.height()) << endl;*/
// Region of the rect we should draw, calculated in viewport
// coordinates, as a region can't handle bigger coordinates
@@ -959,12 +959,12 @@ void KexiTableView::paintEmptyArea( TQPainter *p, int cx, int cy, int cw, int ch
// reg = reg.subtract( TQRect( TQPoint( 0, 0 ), ts ) );
// And draw the rectangles (transformed inc contents coordinates as needed)
- TQMemArray<TQRect> r = reg.tqrects();
+ TQMemArray<TQRect> r = reg.rects();
for ( int i = 0; i < (int)r.count(); i++ ) {
TQRect rect( viewportToContents2(r[i].topLeft()), r[i].size() );
/* kdDebug(44021) << TQString("- pEA: p->fillRect(x:%1 y:%2 w:%3 h:%4)")
- .tqarg(rect.x()).tqarg(rect.y())
- .tqarg(rect.width()).tqarg(rect.height()) << endl;*/
+ .arg(rect.x()).arg(rect.y())
+ .arg(rect.width()).arg(rect.height()) << endl;*/
// p->fillRect( TQRect(viewportToContents2(r[i].topLeft()),r[i].size()), d->emptyAreaColor );
p->fillRect( rect, d->appearance.emptyAreaColor );
// p->fillRect( TQRect(viewportToContents2(r[i].topLeft()),r[i].size()), viewport()->backgroundBrush() );
@@ -1425,7 +1425,7 @@ void KexiTableView::keyPressEvent(TQKeyEvent* e)
else {
kexidbg << "KexiTableView::KeyPressEvent(): default" << endl;
if (e->text().isEmpty() || !e->text().isEmpty() && !e->text()[0].isPrint() ) {
- kdDebug(44021) << "NOT PRINTABLE: 0x0" << TQString("%1").tqarg(k,0,16) <<endl;
+ kdDebug(44021) << "NOT PRINTABLE: 0x0" << TQString("%1").arg(k,0,16) <<endl;
// e->ignore();
TQScrollView::keyPressEvent(e);
return;
@@ -1450,7 +1450,7 @@ void KexiTableView::keyPressEvent(TQKeyEvent* e)
m_vScrollBarValueChanged_enabled=false;
- // if focus cell changes, tqrepaint
+ // if focus cell changes, repaint
setCursorPosition(curRow, curCol);
m_vScrollBarValueChanged_enabled=true;
@@ -1630,7 +1630,7 @@ void KexiTableView::resizeEvent(TQResizeEvent *e)
slotUpdate();
triggerUpdate();
}
-// d->pTopHeader->tqrepaint();
+// d->pTopHeader->repaint();
/* m_navPanel->setGeometry(
@@ -1645,14 +1645,14 @@ void KexiTableView::resizeEvent(TQResizeEvent *e)
// m_navPanel->setGeometry(1,horizontalScrollBar()->pos().y(),
// m_navPanel->width(), horizontalScrollBar()->height());
// updateContents(0,0,2000,2000);//js
-// erase(); tqrepaint();
+// erase(); repaint();
}
void KexiTableView::viewportResizeEvent( TQResizeEvent *e )
{
TQScrollView::viewportResizeEvent( e );
updateGeometries();
-// erase(); tqrepaint();
+// erase(); repaint();
}
void KexiTableView::showEvent(TQShowEvent *e)
@@ -1818,7 +1818,7 @@ void KexiTableView::slotColumnWidthChanged( int, int, int )
else {
// updateContents( columnPos(col), 0, contentsWidth(), contentsHeight() );
updateContents(contentsX(), 0, viewport()->width(), contentsHeight());
- // viewport()->tqrepaint();
+ // viewport()->repaint();
}
// updateContents(0, 0, d->pBufferPm->width(), d->pBufferPm->height());
@@ -2481,7 +2481,7 @@ bool KexiTableView::eventFilter( TQObject *o, TQEvent *e )
const bool hp = KexiUtils::hasParent( static_cast<TQWidget*>(o), focusWidget());
if (!hp && KexiUtils::hasParent( this, static_cast<TQWidget*>(o))) {
//accept row editing if focus is moved to foreign widget
- //(not a child, like eg. editor) from one of our table view's tqchildren
+ //(not a child, like eg. editor) from one of our table view's children
//or from table view itself
if (!acceptRowEdit()) {
static_cast<TQWidget*>(o)->setFocus();
diff --git a/kexi/widget/tableview/kexitableviewdata.cpp b/kexi/widget/tableview/kexitableviewdata.cpp
index ad670e3e..6a15b0db 100644
--- a/kexi/widget/tableview/kexitableviewdata.cpp
+++ b/kexi/widget/tableview/kexitableviewdata.cpp
@@ -635,7 +635,7 @@ bool KexiTableViewData::updateRowEditBufferRef(KexiTableItem *item,
}
//! @todo if there're multiple views for this data, we need multiple buffers!
-bool KexiTableViewData::saveRow(KexiTableItem& item, bool insert, bool tqrepaint)
+bool KexiTableViewData::saveRow(KexiTableItem& item, bool insert, bool repaint)
{
if (!m_pRowEditBuffer)
return true; //nothing to do
@@ -655,7 +655,7 @@ bool KexiTableViewData::saveRow(KexiTableItem& item, bool insert, bool tqrepaint
if (val->isNull() && !f->isAutoIncrement()) {
//NOT NULL violated
m_result.msg = i18n("\"%1\" column requires a value to be entered.")
- .tqarg(f->captionOrName()) + "\n\n" + Kexi::msgYouCanImproveData();
+ .arg(f->captionOrName()) + "\n\n" + Kexi::msgYouCanImproveData();
m_result.desc = i18n("The column's constraint is declared as NOT NULL.");
m_result.column = col;
return false;
@@ -666,7 +666,7 @@ bool KexiTableViewData::saveRow(KexiTableItem& item, bool insert, bool tqrepaint
if (!f->isAutoIncrement() && (val->isNull() || KexiDB::isEmptyValue( f, *val ))) {
//NOT EMPTY violated
m_result.msg = i18n("\"%1\" column requires a value to be entered.")
- .tqarg(f->captionOrName()) + "\n\n" + Kexi::msgYouCanImproveData();
+ .arg(f->captionOrName()) + "\n\n" + Kexi::msgYouCanImproveData();
m_result.desc = i18n("The column's constraint is declared as NOT EMPTY.");
m_result.column = col;
return false;
@@ -721,12 +721,12 @@ js: TODO: use KexiMainWindowImpl::showErrorMessage(const TQString &title, KexiDB
m_pRowEditBuffer->clear();
- if (tqrepaint)
+ if (repaint)
emit rowRepaintRequested(item);
return true;
}
-bool KexiTableViewData::saveRowChanges(KexiTableItem& item, bool tqrepaint)
+bool KexiTableViewData::saveRowChanges(KexiTableItem& item, bool repaint)
{
kdDebug() << "KexiTableViewData::saveRowChanges()..." << endl;
m_result.clear();
@@ -734,32 +734,32 @@ bool KexiTableViewData::saveRowChanges(KexiTableItem& item, bool tqrepaint)
if (!m_result.success)
return false;
- if (saveRow(item, false /*update*/, tqrepaint)) {
+ if (saveRow(item, false /*update*/, repaint)) {
emit rowUpdated(&item);
return true;
}
return false;
}
-bool KexiTableViewData::saveNewRow(KexiTableItem& item, bool tqrepaint)
+bool KexiTableViewData::saveNewRow(KexiTableItem& item, bool repaint)
{
kdDebug() << "KexiTableViewData::saveNewRow()..." << endl;
m_result.clear();
- emit aboutToInsertRow(&item, &m_result, tqrepaint);
+ emit aboutToInsertRow(&item, &m_result, repaint);
if (!m_result.success)
return false;
- if (saveRow(item, true /*insert*/, tqrepaint)) {
- emit rowInserted(&item, tqrepaint);
+ if (saveRow(item, true /*insert*/, repaint)) {
+ emit rowInserted(&item, repaint);
return true;
}
return false;
}
-bool KexiTableViewData::deleteRow(KexiTableItem& item, bool tqrepaint)
+bool KexiTableViewData::deleteRow(KexiTableItem& item, bool repaint)
{
m_result.clear();
- emit aboutToDeleteRow(item, &m_result, tqrepaint);
+ emit aboutToDeleteRow(item, &m_result, repaint);
if (!m_result.success)
return false;
@@ -784,9 +784,9 @@ bool KexiTableViewData::deleteRow(KexiTableItem& item, bool tqrepaint)
return true;
}
-void KexiTableViewData::deleteRows( const TQValueList<int> &rowsToDelete, bool tqrepaint )
+void KexiTableViewData::deleteRows( const TQValueList<int> &rowsToDelete, bool repaint )
{
- Q_UNUSED( tqrepaint );
+ Q_UNUSED( repaint );
if (rowsToDelete.isEmpty())
return;
@@ -804,11 +804,11 @@ void KexiTableViewData::deleteRows( const TQValueList<int> &rowsToDelete, bool t
emit rowsDeleted( rowsToDelete );
}
-void KexiTableViewData::insertRow(KexiTableItem& item, uint index, bool tqrepaint)
+void KexiTableViewData::insertRow(KexiTableItem& item, uint index, bool repaint)
{
if (!insert( index = TQMIN(index, count()), &item ))
return;
- emit rowInserted(&item, index, tqrepaint);
+ emit rowInserted(&item, index, repaint);
}
void KexiTableViewData::clearInternal()
@@ -827,7 +827,7 @@ void KexiTableViewData::clearInternal()
}
}
-bool KexiTableViewData::deleteAllRows(bool tqrepaint)
+bool KexiTableViewData::deleteAllRows(bool repaint)
{
clearInternal();
@@ -837,7 +837,7 @@ bool KexiTableViewData::deleteAllRows(bool tqrepaint)
res = m_cursor->deleteAllRows();
}
- if (tqrepaint)
+ if (repaint)
emit reloadRequested();
return res;
}
diff --git a/kexi/widget/tableview/kexitableviewdata.h b/kexi/widget/tableview/kexitableviewdata.h
index 7263f3fe..eb3d20df 100644
--- a/kexi/widget/tableview/kexitableviewdata.h
+++ b/kexi/widget/tableview/kexitableviewdata.h
@@ -359,27 +359,27 @@ public:
/*! \return last operation's result information (always not null). */
inline KexiDB::ResultInfo* result() { return &m_result; }
- bool saveRowChanges(KexiTableItem& item, bool tqrepaint = false);
+ bool saveRowChanges(KexiTableItem& item, bool repaint = false);
- bool saveNewRow(KexiTableItem& item, bool tqrepaint = false);
+ bool saveNewRow(KexiTableItem& item, bool repaint = false);
- bool deleteRow(KexiTableItem& item, bool tqrepaint = false);
+ bool deleteRow(KexiTableItem& item, bool repaint = false);
/*! Deletes rows (by number) passed with \a rowsToDelete.
Currently, this method is only for non data-aware tables. */
- void deleteRows( const TQValueList<int> &rowsToDelete, bool tqrepaint = false );
+ void deleteRows( const TQValueList<int> &rowsToDelete, bool repaint = false );
/*! Deletes all rows. Works either for db-aware and non db-aware tables.
Column's definition is not changed.
For db-aware version, all rows are removed from a database.
Row-edit buffer is cleared.
- If \a tqrepaint is true, reloadRequested() signal
+ If \a repaint is true, reloadRequested() signal
is emitted after deleting (if at least one row was deleted),
- so presenters can tqrepaint their contents.
+ so presenters can repaint their contents.
\return true on success. */
- virtual bool deleteAllRows(bool tqrepaint = false);
+ virtual bool deleteAllRows(bool repaint = false);
/*! @internal method, used mostly by specialized classes like KexiTableView.
Clears internal row structures. Row-edit buffer is cleared.
@@ -390,7 +390,7 @@ public:
/*! Inserts new \a item at index \a index.
\a item will be owned by this data object.
Note: Reasonable only for not not-db-aware version. */
- void insertRow(KexiTableItem& item, uint index, bool tqrepaint = false);
+ void insertRow(KexiTableItem& item, uint index, bool repaint = false);
/*TODO: add this as well?
void insertRow(KexiTableItem& item, KexiTableItem& aboveItem); */
@@ -445,7 +445,7 @@ signals:
/*! Emited before inserting of a new, current row.
Connect this signal to your slot and set \a result->success to false
to disallow this inserting. You can also change columns in \a item row. */
- void aboutToInsertRow(KexiTableItem *item, KexiDB::ResultInfo* result, bool tqrepaint);
+ void aboutToInsertRow(KexiTableItem *item, KexiDB::ResultInfo* result, bool repaint);
/*! Emited before changing of an edited, current row.
Connect this signal to your slot and set \a result->success to false
@@ -455,15 +455,15 @@ signals:
void rowUpdated(KexiTableItem*); //!< Current row has been updated
- void rowInserted(KexiTableItem*, bool tqrepaint); //!< A row has been inserted
+ void rowInserted(KexiTableItem*, bool repaint); //!< A row has been inserted
//! A row has been inserted at \a index position (not db-aware data only)
- void rowInserted(KexiTableItem*, uint index, bool tqrepaint);
+ void rowInserted(KexiTableItem*, uint index, bool repaint);
/*! Emited before deleting of a current row.
Connect this signal to your slot and set \a result->success to false
to disallow this deleting. */
- void aboutToDeleteRow(KexiTableItem& item, KexiDB::ResultInfo* result, bool tqrepaint);
+ void aboutToDeleteRow(KexiTableItem& item, KexiDB::ResultInfo* result, bool repaint);
//! Current row has been deleted
void rowDeleted();
@@ -497,7 +497,7 @@ protected:
int cmpBLOB(Item item1, Item item2);
//! internal: for saveRowChanges() and saveNewRow()
- bool saveRow(KexiTableItem& item, bool insert, bool tqrepaint);
+ bool saveRow(KexiTableItem& item, bool insert, bool repaint);
//! (logical) sorted column number, set by setSorting()
//! can differ from m_realSortedColumn if there's lookup column used
diff --git a/kexi/widget/utils/kexicontextmenuutils.cpp b/kexi/widget/utils/kexicontextmenuutils.cpp
index f34864a9..aeeec86d 100644
--- a/kexi/widget/utils/kexicontextmenuutils.cpp
+++ b/kexi/widget/utils/kexicontextmenuutils.cpp
@@ -187,7 +187,7 @@ void KexiImageContextMenu::saveAs()
if (f.exists() && KMessageBox::Yes != KMessageBox::warningYesNo(this,
"<qt>"+i18n("File \"%1\" already exists."
"<p>Do you want to replace it with a new one?")
- .tqarg(TQDir::convertSeparators(fileName))+"</qt>",0,
+ .arg(TQDir::convertSeparators(fileName))+"</qt>",0,
KGuiItem(i18n("&Replace")), KGuiItem(i18n("&Don't Replace"))))
{
return;
@@ -268,8 +268,8 @@ bool KexiContextMenuUtils::updateTitle(TQPopupMenu *menu, const TQString& object
/*! @todo look at makeFirstCharacterUpperCaseInCaptions setting [bool]
(see doc/dev/settings.txt) */
TQString realTitle( i18n("Object name : Object type", "%1 : %2")
- .tqarg( objectName[0].upper() + objectName.mid(1) )
- .tqarg( objectTypeName ));
+ .arg( objectName[0].upper() + objectName.mid(1) )
+ .arg( objectTypeName ));
if (iconName.isEmpty())
title->setTitle(realTitle);
diff --git a/kexi/widget/utils/kexidatetimeformatter.cpp b/kexi/widget/utils/kexidatetimeformatter.cpp
index b11961d2..298eda48 100644
--- a/kexi/widget/utils/kexidatetimeformatter.cpp
+++ b/kexi/widget/utils/kexidatetimeformatter.cpp
@@ -78,7 +78,7 @@ KexiDateFormatter::KexiDateFormatter()
m_order = TQDateEdit::YDM;
//! @todo use TQRegExp (to replace %Y by %1, etc.) instead of hardcoded "%1%299%399"
//! because df may contain also other characters
- m_inputMask = TQString("%1%299%399").tqarg(yearMask).tqarg(m_separator).tqarg(m_separator);
+ m_inputMask = TQString("%1%299%399").arg(yearMask).arg(m_separator).arg(m_separator);
m_qtFormat = yearDateFormat+m_separator+dayDateFormat+m_separator+monthDateFormat;
m_yearpos = 0;
m_daypos = yearMask.length()+separatorLen;
@@ -86,7 +86,7 @@ KexiDateFormatter::KexiDateFormatter()
}
else if (daypos<monthpos && monthpos<yearpos) {
m_order = TQDateEdit::DMY;
- m_inputMask = TQString("99%199%2%3").tqarg(m_separator).tqarg(m_separator).tqarg(yearMask);
+ m_inputMask = TQString("99%199%2%3").arg(m_separator).arg(m_separator).arg(yearMask);
m_qtFormat = dayDateFormat+m_separator+monthDateFormat+m_separator+yearDateFormat;
m_daypos = 0;
m_monthpos = 2+separatorLen;
@@ -94,7 +94,7 @@ KexiDateFormatter::KexiDateFormatter()
}
else if (monthpos<daypos && daypos<yearpos) {
m_order = TQDateEdit::MDY;
- m_inputMask = TQString("99%199%2%3").tqarg(m_separator).tqarg(m_separator).tqarg(yearMask);
+ m_inputMask = TQString("99%199%2%3").arg(m_separator).arg(m_separator).arg(yearMask);
m_qtFormat = monthDateFormat+m_separator+dayDateFormat+m_separator+yearDateFormat;
m_monthpos = 0;
m_daypos = 2+separatorLen;
@@ -104,7 +104,7 @@ KexiDateFormatter::KexiDateFormatter()
ok = false;
}
if (!ok || m_order == TQDateEdit::YMD) {//default: YMD
- m_inputMask = TQString("%1%299%399").tqarg(yearMask).tqarg(m_separator).tqarg(m_separator);
+ m_inputMask = TQString("%1%299%399").arg(yearMask).arg(m_separator).arg(m_separator);
m_qtFormat = yearDateFormat+m_separator+monthDateFormat+m_separator+dayDateFormat;
m_yearpos = 0;
m_monthpos = yearMask.length()+separatorLen;
diff --git a/kexi/widget/utils/kexiflowlayout.cpp b/kexi/widget/utils/kexiflowlayout.cpp
index 50959770..f6868a5e 100644
--- a/kexi/widget/utils/kexiflowlayout.cpp
+++ b/kexi/widget/utils/kexiflowlayout.cpp
@@ -134,9 +134,9 @@ KexiFlowLayout::widgetList() const
}
void
-KexiFlowLayout::tqinvalidate()
+KexiFlowLayout::invalidate()
{
- TQLayout::tqinvalidate();
+ TQLayout::invalidate();
m_cached_sizeHint = TQSize();
m_cached_minSize = TQSize();
m_cached_width = 0;
@@ -468,7 +468,7 @@ int KexiFlowLayout::count() const {
\reimp
*/
TQLayoutItem* KexiFlowLayout::itemAt(int index) const {
- return index >= 0 && index < m_list.count() ? (const_cast<TQPtrList<TQLayoutItem>&>(m_list).tqat(index)) : 0;
+ return index >= 0 && index < m_list.count() ? (const_cast<TQPtrList<TQLayoutItem>&>(m_list).at(index)) : 0;
}
/*!
@@ -477,8 +477,8 @@ TQLayoutItem* KexiFlowLayout::itemAt(int index) const {
TQLayoutItem* KexiFlowLayout::takeAt(int index) {
if (index < 0 || index >= m_list.count())
return 0;
- TQLayoutItem *item = m_list.tqat(index);
- m_list.remove(m_list.tqat(index));
+ TQLayoutItem *item = m_list.at(index);
+ m_list.remove(m_list.at(index));
delete item;
invalidate();
diff --git a/kexi/widget/utils/kexiflowlayout.h b/kexi/widget/utils/kexiflowlayout.h
index c4550fca..aec6c6c3 100644
--- a/kexi/widget/utils/kexiflowlayout.h
+++ b/kexi/widget/utils/kexiflowlayout.h
@@ -49,7 +49,7 @@ class KEXIGUIUTILS_EXPORT KexiFlowLayout : public TQLayout
virtual void addItem(TQLayoutItem *item);
virtual void addSpacing(int size);
virtual TQLayoutIterator iterator();
- virtual void tqinvalidate();
+ virtual void invalidate();
virtual bool hasHeightForWidth() const;
virtual int heightForWidth(int width) const;
diff --git a/kexi/widget/utils/kexigradientwidget.cpp b/kexi/widget/utils/kexigradientwidget.cpp
index 18d34447..d93b13ff 100644
--- a/kexi/widget/utils/kexigradientwidget.cpp
+++ b/kexi/widget/utils/kexigradientwidget.cpp
@@ -155,7 +155,7 @@ void KexiGradientWidget::rebuildCache( void ) {
}
/**
- All tqchildren need to have our background set.
+ All children need to have our background set.
*/
KPixmap partPixmap;
TQRect area;
@@ -180,7 +180,7 @@ void KexiGradientWidget::rebuildCache( void ) {
under the current child-widget.
*/
if ( TQT_BASE_OBJECT(childWidget->parent()) == TQT_BASE_OBJECT(this) ) {
- area = childWidget->tqgeometry();
+ area = childWidget->geometry();
} else {
area.setTopLeft( childWidget->mapTo( this,
childWidget->clipRegion().boundingRect().topLeft() ) );
@@ -311,7 +311,7 @@ void KexiGradientWidget::updateChildBackground( TQWidget* childWidget )
/**
Exclude widgtes that don't have a parent.
- This happens when tqchildren are removed
+ This happens when children are removed
which are in the knownWidgets-list.
*/
if ( childWidget->parent() == 0L )
@@ -330,7 +330,7 @@ void KexiGradientWidget::updateChildBackground( TQWidget* childWidget )
under the current child-widget.
*/
if ( TQT_BASE_OBJECT(childWidget->parent()) == TQT_BASE_OBJECT(this) ) {
- area = childWidget->tqgeometry();
+ area = childWidget->geometry();
} else {
area.setTopLeft( childWidget->mapTo( this,
childWidget->clipRegion().boundingRect().topLeft() ) );
diff --git a/kexi/widget/utils/kexigradientwidget.h b/kexi/widget/utils/kexigradientwidget.h
index 3f9b894d..d11c4f04 100644
--- a/kexi/widget/utils/kexigradientwidget.h
+++ b/kexi/widget/utils/kexigradientwidget.h
@@ -184,11 +184,11 @@ class KEXIGUIUTILS_EXPORT KexiGradientWidget : public TQWidget {
private:
/*!
- Builds a list of tqchildren of \a p.
+ Builds a list of children of \a p.
Only widgets that work correctly with KexiGradientWidget
will be in this list.
The results will be stored in \a list.
- The method recursively calls itself until all tqchildren of \a p
+ The method recursively calls itself until all children of \a p
have been found and stored in the list.
*/
static void buildChildrenList( WidgetList& list, TQWidget* p );
diff --git a/kexi/widget/utils/kexirecordnavigator.h b/kexi/widget/utils/kexirecordnavigator.h
index 9eae328b..6c666e78 100644
--- a/kexi/widget/utils/kexirecordnavigator.h
+++ b/kexi/widget/utils/kexirecordnavigator.h
@@ -87,7 +87,7 @@ class KEXIGUIUTILS_EXPORT KexiRecordNavigator : public TQFrame
/*! \return record count displayed for this navigator. */
uint recordCount() const;
- /*! Sets horizontal bar's \a hbar (at the bottom) tqgeometry so this record navigator
+ /*! Sets horizontal bar's \a hbar (at the bottom) geometry so this record navigator
is properly positioned together with horizontal scroll bar. This method is used
in TQScrollView::setHBarGeometry() implementations:
see KexiTableView::setHBarGeometry() and KexiFormScrollView::setHBarGeometry()
diff --git a/kexi/widget/tableview/kexidataawareobjectiface.h b/kexi/widget/tableview/kexidataawareobjectiface.h
index 389c1c74..0fed82b6 100644
--- a/kexi/widget/tableview/kexidataawareobjectiface.h
+++ b/kexi/widget/tableview/kexidataawareobjectiface.h
@@ -267,14 +267,14 @@ class KEXIDATATABLE_EXPORT KexiDataAwareObjectInterface
Does not clear columns information.
Does not destroy KexiTableViewData object (if present) but only clears its contents.
Displays confirmation dialog if \a ask is true (the default is false).
- Repaints widget if \a tqrepaint is true (the default).
+ Repaints widget if \a repaint is true (the default).
For empty tables, true is returned immediately.
If isDeleteEnabled() is false, false is returned.
For spreadsheet mode all current rows are just replaced by empty rows.
\return true on success, false on failure, and cancelled if user cancelled deletion
(only possible if \a ask is true).
*/
- tristate deleteAllRows(bool ask = false, bool tqrepaint = true);
+ tristate deleteAllRows(bool ask = false, bool repaint = true);
/*! \return maximum number of rows that can be displayed per one "page"
for current view's size. */
@@ -537,12 +537,12 @@ class KEXIDATATABLE_EXPORT KexiDataAwareObjectInterface
virtual void initDataContents();
/*! Clears columns information and thus all internal table data
- and its visible representation. Repaints widget if \a tqrepaint is true. */
- virtual void clearColumns(bool tqrepaint = true);
+ and its visible representation. Repaints widget if \a repaint is true. */
+ virtual void clearColumns(bool repaint = true);
/*! Called by clearColumns() to clear internals of the object.
For example, KexiTableView removes contents of it's horizontal header. */
- virtual void clearColumnsInternal(bool tqrepaint) = 0;
+ virtual void clearColumnsInternal(bool repaint) = 0;
/*! @internal for implementation
This should append another section within horizontal header or any sort of caption
@@ -654,16 +654,16 @@ class KEXIDATATABLE_EXPORT KexiDataAwareObjectInterface
//! Handles KexiTableViewData::aboutToDeleteRow() signal. Prepares info for slotRowDeleted().
virtual void slotAboutToDeleteRow(KexiTableItem& item, KexiDB::ResultInfo* result,
- bool tqrepaint);
+ bool repaint);
- //! Handles KexiTableViewData::rowDeleted() signal to tqrepaint when needed.
+ //! Handles KexiTableViewData::rowDeleted() signal to repaint when needed.
virtual void slotRowDeleted();
- //! Handles KexiTableViewData::rowInserted() signal to tqrepaint when needed.
- virtual void slotRowInserted(KexiTableItem *item, bool tqrepaint);
+ //! Handles KexiTableViewData::rowInserted() signal to repaint when needed.
+ virtual void slotRowInserted(KexiTableItem *item, bool repaint);
//! Like above, not db-aware version
- virtual void slotRowInserted(KexiTableItem *item, uint row, bool tqrepaint);
+ virtual void slotRowInserted(KexiTableItem *item, uint row, bool repaint);
virtual void slotRowsDeleted( const TQValueList<int> & ) {}
@@ -675,7 +675,7 @@ class KEXIDATATABLE_EXPORT KexiDataAwareObjectInterface
virtual void selectCellInternal() {}
/*! Used in KexiDataAwareObjectInterface::slotRowDeleted()
- to tqrepaint tow \a row and all visible below.
+ to repaint tow \a row and all visible below.
Implemented if there is more than one row displayed, i.e. currently for KexiTableView. */
virtual void updateAllVisibleRowsBelow(int row) { Q_UNUSED( row ); }
diff --git a/kexi/widget/tableview/kexitableview.h b/kexi/widget/tableview/kexitableview.h
index daabe0f9..fc488c83 100644
--- a/kexi/widget/tableview/kexitableview.h
+++ b/kexi/widget/tableview/kexitableview.h
@@ -263,7 +263,7 @@ public slots:
virtual void setData( KexiTableViewData *data, bool owner = true )
{ KexiDataAwareObjectInterface::setData( data, owner ); }
- virtual void clearColumnsInternal(bool tqrepaint);
+ virtual void clearColumnsInternal(bool repaint);
/*! Adjusts \a colNum column's width to its (current) contents.
If \a colNum == -1, all columns' width is adjusted. */
@@ -432,19 +432,19 @@ protected slots:
virtual void slotRowRepaintRequested(KexiTableItem& item);
//! Handles KexiTableViewData::aboutToDeleteRow() signal. Prepares info for slotRowDeleted().
- virtual void slotAboutToDeleteRow(KexiTableItem& item, KexiDB::ResultInfo* result, bool tqrepaint)
- { KexiDataAwareObjectInterface::slotAboutToDeleteRow(item, result, tqrepaint); }
+ virtual void slotAboutToDeleteRow(KexiTableItem& item, KexiDB::ResultInfo* result, bool repaint)
+ { KexiDataAwareObjectInterface::slotAboutToDeleteRow(item, result, repaint); }
- //! Handles KexiTableViewData::rowDeleted() signal to tqrepaint when needed.
+ //! Handles KexiTableViewData::rowDeleted() signal to repaint when needed.
virtual void slotRowDeleted() { KexiDataAwareObjectInterface::slotRowDeleted(); }
- //! Handles KexiTableViewData::rowInserted() signal to tqrepaint when needed.
- virtual void slotRowInserted(KexiTableItem *item, bool tqrepaint)
- { KexiDataAwareObjectInterface::slotRowInserted(item, tqrepaint); }
+ //! Handles KexiTableViewData::rowInserted() signal to repaint when needed.
+ virtual void slotRowInserted(KexiTableItem *item, bool repaint)
+ { KexiDataAwareObjectInterface::slotRowInserted(item, repaint); }
//! Like above, not db-aware version
- virtual void slotRowInserted(KexiTableItem *item, uint row, bool tqrepaint)
- { KexiDataAwareObjectInterface::slotRowInserted(item, row, tqrepaint); }
+ virtual void slotRowInserted(KexiTableItem *item, uint row, bool repaint)
+ { KexiDataAwareObjectInterface::slotRowInserted(item, row, repaint); }
/*! Handles verticalScrollBar()'s valueChanged(int) signal.
Called when vscrollbar's value has been changed. */
@@ -588,7 +588,7 @@ protected:
virtual void removeEditor();
//! Internal: updated sched fonts for painting.
- void updateFonts(bool tqrepaint = false);
+ void updateFonts(bool repaint = false);
/*! @internal Changes bottom margin settings, in pixels.
At this time, it's used by KexiComboBoxPopup to decrease margin for popup's table. */
@@ -614,7 +614,7 @@ protected:
virtual void paste();
/*! Used in KexiDataAwareObjectInterface::slotRowDeleted()
- to tqrepaint tow \a row and all visible below. */
+ to repaint tow \a row and all visible below. */
virtual void updateAllVisibleRowsBelow(int row);
void updateAfterCancelRowEdit();
@@ -626,7 +626,7 @@ protected:
bool getVisibleLookupValue(TQVariant& cellValue, KexiTableEdit *edit,
KexiTableItem *item, KexiTableViewColumn *tvcol) const;
// //! Called to tqrepaint contents after a row is deleted.
// void repaintAfterDelete();
KexiTableViewPrivate *d;
@@ -626,7 +626,7 @@ protected:
bool getVisibleLookupValue(TQVariant& cellValue, KexiTableEdit *edit,
KexiTableItem *item, KexiTableViewColumn *tvcol) const;
-// //! Called to tqrepaint contents after a row is deleted.
+// //! Called to repaint contents after a row is deleted.
// void repaintAfterDelete();
KexiTableViewPrivate *d;